import(laeken)
import(stats)
import(survey)

importFrom("grDevices", "dev.print", "dev.set", "heat.colors", "pdf")
importFrom("graphics", "abline", "box", "contour", "curve", "image",
           "legend", "lines", "mtext", "par", "text")

importFrom(hypergeo, isgood, genhypergeo_series)
importFrom(numDeriv, grad, jacobian)
importFrom(cubature, adaptIntegrate)

export(
 dgb2,
 pgb2,
 qgb2,
 rgb2,
 moment.gb2,
 incompl.gb2,
 el.gb2,
 vl.gb2,
 sl.gb2,
 kl.gb2,
 arpt.gb2,
 arpr.gb2,
 rmpg.gb2,
 qsr.gb2,
 Thomae,
 gb2.gini,
 gini.gb2,
 gini.b2,
 gini.dag,
 gini.sm,
 main.gb2,
 main2.gb2,
 logf.gb2,
 dlogf.gb2,
 d2logf.gb2,
 loglp.gb2,
 loglh.gb2,
 scoresp.gb2,
 scoresh.gb2,
 info.gb2,
 prof.gb2,
 proflogl.gb2,
 profscores.gb2,
 fisk,
 fiskh,
 ml.gb2,
 mlh.gb2,
 profml.gb2,
 main.emp,
 mlfit.gb2,
 nlsfit.gb2,
 plotsML.gb2,
 robwts,
 saveplot,
 contprof.gb2,
 contindic.gb2,
 varscore.gb2,
 vepar.gb2,
 derivind.gb2,
 veind.gb2,
 fg.cgb2,
 dl.cgb2,
 pl.cgb2,
 dcgb2,
 pcgb2,
 prcgb2,
 mkl.cgb2,
 moment.cgb2,
 incompl.cgb2,
 qcgb2,
 rcgb2,
 arpt.cgb2,
 arpr.cgb2,
 rmpg.cgb2,
 qsr.cgb2,
 main.cgb2,
 vofp.cgb2,
 pofv.cgb2,
 logl.cgb2,
 scoreU.cgb2,
 scores.cgb2,
 ml.cgb2,
 dplot.cgb2,
 varscore.cgb2,
 desvar.cgb2,
 hess.cgb2,
 vepar.cgb2,
 derivind.cgb2,
 veind.cgb2,
 pkl.cavgb2,
 lambda0.cavgb2,
 logl.cavgb2,
 scores.cavgb2,
 scoreU.cavgb2,
 scorez.cavgb2,
 ml.cavgb2,
 dplot.cavgb2,
 varscore.cavgb2,
 desvar.cavgb2,
 hess.cavgb2,
 vepar.cavgb2,
 veind.cavgb2
 )


